@@ -14,6 +14,7 @@ use Date::Lectionary::Time qw(isSunday prevSunday);
 use Date::Lectionary::Day;
 use namespace::autoclean;
 use Moose::Util::TypeConstraints;
+use MooseX::StrictConstructor;
 
 =head1 NAME
 
@@ -21,7 +22,7 @@ Date::Lectionary::Daily - Daily Readings for the Christian Lectionary
 
 =head1 VERSION
 
-Version 1.20171127
+Version 1.20180114
 
 =cut
 
@@ -39,7 +40,7 @@ Date::Lectionary::Daily takes a Time::Piece date and returns ACNA readings for m
 
 =cut
 
-our $VERSION = '1.20171127';
+our $VERSION = '1.20180114';
 
 enum 'LectionaryType', [qw(acna)];
 no Moose::Util::TypeConstraints;
@@ -270,13 +271,15 @@ Many thanks to my beautiful wife, Jennifer, and my amazing daughter, Rosemary.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2017 Michael Wayne Arnold.
+Copyright 2017 MICHAEL WAYNE ARNOLD
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
+Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 
-See L<http://dev.perl.org/licenses/> for more information.
+1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
+
+2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
+
+THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 =cut
